==> openmsx-0.6.0.tar.gz: openmsx-0.6.0/src/video/VideoLayer.cc <==
// $Id: VideoLayer.cc,v 1.16 2005/11/11 23:04:19 manuelbi Exp $

#include "VideoLayer.hh"
#include "RenderSettings.hh"
#include "Display.hh"
#include "CommandController.hh"
#include "GlobalSettings.hh"
#include "BooleanSetting.hh"
#include <cassert>

namespace openmsx {

VideoLayer::VideoLayer(VideoSource videoSource_,
                       CommandController& commandController,
                       RenderSettings& renderSettings_,
                       Display& display_)
	: videoSource(videoSource_)
	, renderSettings(renderSettings_)
	, display(display_)
	, videoSourceSetting(renderSettings.getVideoSource())
	, videoSourceActivator(videoSourceSetting, videoSource)
	, powerSetting(commandController.getGlobalSettings().getPowerSetting())
{
	setCoverage(getCoverage());
	setZ(calcZ());
	display.addLayer(*this);

	videoSourceSetting.attach(*this);
	powerSetting.attach(*this);
}

VideoLayer::~VideoLayer()
{
	powerSetting.detach(*this);
	videoSourceSetting.detach(*this);

	display.removeLayer(*this);
}

VideoSource VideoLayer::getVideoSource() const
{
	return videoSource;
}

void VideoLayer::update(const Setting& setting)
{
	if (&setting == &videoSourceSetting) {
		setZ(calcZ());
	} else if (&setting == &powerSetting) {
		setCoverage(getCoverage());
	} else {
		assert(false);
	}
}

Layer::ZIndex VideoLayer::calcZ()
{
	return renderSettings.getVideoSource().getValue() == videoSource
		? Z_MSX_ACTIVE
		: Z_MSX_PASSIVE;
}

Layer::Coverage VideoLayer::getCoverage()
{
	return powerSetting.getValue()
		? COVER_FULL
		: COVER_NONE;
}

} // namespace openmsx

==> openmsx-0.6.1.tar.gz: openmsx-0.6.1/src/video/VideoLayer.cc <==
// $Id: VideoLayer.cc,v 1.20 2006/04/05 08:13:25 m9710797 Exp $

#include "VideoLayer.hh"
#include "RenderSettings.hh"
#include "Display.hh"
#include "CommandController.hh"
#include "GlobalSettings.hh"
#include "BooleanSetting.hh"
#include "VideoSourceSetting.hh"
#include <cassert>

namespace openmsx {

VideoLayer::VideoLayer(VideoSource videoSource_,
                       CommandController& commandController,
                       Display& display_)
	: videoSource(videoSource_)
	, display(display_)
	, renderSettings(display.getRenderSettings())
	, videoSourceSetting(renderSettings.getVideoSource())
	, videoSourceActivator(videoSourceSetting, videoSource)
	, powerSetting(commandController.getGlobalSettings().getPowerSetting())
{
	setCoverage(getCoverage());
	setZ(calcZ());
	display.addLayer(*this);

	videoSourceSetting.attach(*this);
	powerSetting.attach(*this);
}

VideoLayer::~VideoLayer()
{
	powerSetting.detach(*this);
	videoSourceSetting.detach(*this);

	display.removeLayer(*this);
}

VideoSource VideoLayer::getVideoSource() const
{
	return videoSource;
}

void VideoLayer::update(const Setting& setting)
{
	if (&setting == &videoSourceSetting) {
		setZ(calcZ());
	} else if (&setting == &powerSetting) {
		setCoverage(getCoverage());
	}
}

Layer::ZIndex VideoLayer::calcZ()
{
	return renderSettings.getVideoSource().getValue() == videoSource
		? Z_MSX_ACTIVE
		: Z_MSX_PASSIVE;
}

Layer::Coverage VideoLayer::getCoverage()
{
	return powerSetting.getValue()
		? COVER_FULL
		: COVER_NONE;
}

} // namespace openmsx
